SpscProducer

Struct SpscProducer 

pub struct SpscProducer<T, const N: usize> { /* private fields */ }
Producer half of an SpscRing.

Implementations

Source

impl<T, const N: usize> SpscProducer<T, N>

pub fn push(&self, item: T) -> Result<(), T>

Attempts to push an item into the ring without blocking.

Errors

Returns Err(item) if the ring is currently full.

pub fn push_overwrite(&self, item: T) -> Option<T>

Pushes an item into the ring, overwriting the oldest buffered entry if necessary.

Returns the displaced oldest item when an overwrite happens.

pub fn buffered_count(&self) -> usize

Returns the current buffered item count.

pub fn capacity(&self) -> usize

Returns the runtime capacity of the ring.