pub type UnitCompletionCallback = unsafe extern "C" fn(context: *mut c_void, success: bool, error: *const c_char);Expand description
One-shot unit completion callback used by crate::completion::UnitCompletion.
context must remain the exact live context pointer for the callback’s
single invocation. error may be null and is only read when success is
false.