pub struct SpscConsumer<T, const N: usize> { /* private fields */ }Expand description
Consumer half of an SpscRing.
Implementations
Sourceimpl<T, const N: usize> SpscConsumer<T, N>
impl<T, const N: usize> SpscConsumer<T, N>
Sourcepub const fn pop_async(&self) -> PopFuture<'_, T, N> ⓘ
pub const fn pop_async(&self) -> PopFuture<'_, T, N> ⓘ
Returns a future that resolves to the next buffered item, or None once
the producer has been dropped and the ring is empty.
Sourcepub fn buffered_count(&self) -> usize
pub fn buffered_count(&self) -> usize
Returns the current buffered item count.
pub const fn stream(&self) -> SpscConsumerStream<'_, T, N>
Available on crate feature
futures-stream only.Trait Implementations